@@ -10,17 +10,21 @@ from .multiselect import Multiselect
 from .multiselect import MultiselectComponentInfo
 from .number import Number
 from .number import NumberComponentInfo
+from .text import Text
+from .text import TextComponentInfo
 from .select import Select
 from .select import SelectComponentInfo
 
 # TODO add interface to inputs
-GreppoInputs = Union[
-    Number, Select, Multiselect, DrawFeature, BarChart, LineChart
-]
+GreppoCharts = Union[BarChart, LineChart]
+GreppoChartNames = [i.proxy_name() for i in GreppoCharts.__args__]
+
+GreppoInputs = Union[Number, Text, Select, Multiselect, DrawFeature]
 GreppoInputsNames = [i.proxy_name() for i in GreppoInputs.__args__]
 
 ComponentInfo = Union[
     NumberComponentInfo,
+    TextComponentInfo,
     SelectComponentInfo,
     MultiselectComponentInfo,
     DrawFeatureComponentInfo,
