@@ -25,6 +25,7 @@ class BarChart:
         description: str,
         x: list,
         y: list,
+        backgroundColor: str = "#000000",
         input_updates: dict[str, Any] = {},
     ):
         self.input_name = name
@@ -33,9 +34,7 @@ class BarChart:
         self.input_updates = input_updates
 
         # background is defaulted
-        dataset = Dataset(
-            label=description, data=y, backgroundColor="#000000"
-        )
+        dataset = Dataset(label=description, data=y, backgroundColor=backgroundColor)
         self.chartdata = ChartData(labels=x, datasets=[dataset])
 
     def get_value(self):
